shepherd_tag library
Shepherd Tag – Lightweight tagging system for the Shepherd automation suite.
Use @ShepherdTag to annotate your widget files with story/feature identifiers,
ShepherdPageKey to identify entire pages, and ShepherdElementKey to identify
specific UI elements for automated testing via Semantics.
Classes
- ShepherdElementKey
- A widget that wraps its child with Semantics to expose a unique identifier to the Shepherd automation suite and Maestro.
- ShepherdElementMetaData
- Metadata object attached to the widget tree for elements.
- ShepherdPageKey
- A transparent widget that embeds a Shepherd id into the Flutter widget tree via Semantics, making it detectable by the Shepherd CLI during automated test generation and by Maestro during test execution.
- ShepherdPageMetaData
- Metadata object attached to the widget tree for pages.
- ShepherdTag
- Annotation used to tag a Dart file (widget, contract or constant file) with a unique feature identifier for the Shepherd automation suite.